@@ -7,6 +7,7 @@
 
 typedef struct _ComputerInfo ComputerInfo;
 typedef struct _MemoryInfo   MemoryInfo;
+typedef struct _ComputerInfo CPUDevice;
 
 struct _MemoryInfo {
 	gint total;
@@ -26,6 +27,8 @@ struct _ComputerInfo {
 	
 	gint  procno;
 	gchar *processor;
+	gchar *flags;
+	gchar *machine;
 	gint  frequency;
 	gint  family, model, stepping;
 	gint  cachel2;
@@ -42,4 +45,6 @@ GtkWidget *processor_get_widget(void);
 gboolean uptime_update(gpointer data);
 gboolean memory_update(gpointer data);
 
+void hi_show_cpu_info(MainWindow *mainwindow, ComputerInfo *ci);
+
 #endif
