@@ -7,6 +7,8 @@ struct _IDEDevice {
 	gchar *model;
 	
 	gchar *media;
+	gchar *phy_geometry;
+	gchar *log_geometry;
 	gint cache;
 
 	IDEDevice *next;
