@@ -8,13 +8,13 @@ typedef struct _NetDevice	NetDevice;
 struct _NetDevice {
 	gchar *iface;
 	
-	guint recv_bytes;
-	guint recv_errors;
-	guint recv_packets;
+	gulong recv_bytes;
+	gulong recv_errors;
+	gulong recv_packets;
 	
-	guint trans_bytes;
-	guint trans_errors;
-	guint trans_packets;
+	gulong trans_bytes;
+	gulong trans_errors;
+	gulong trans_packets;
 
 	NetDevice *next;
 };
